Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
Types ¶
type ExecResult ¶
type ExecResult struct {
Stdout []byte
Stderr []byte
ExitCode int
Error string
ModTime time.Time
Killed bool
KillReason string
}
convenience structure for return values directly used as parts for the db-models of RunResult and GccResult
func Execute ¶
func Execute(command *Command) (*ExecResult, error)
type IOError ¶
Helper functions to deal with program execution execute returns as following: stdout, stderr, error Where error may be of type IOError with potentially embedded errors that are the original errors (like pipe / fd IO errors). Other error types may be applicable (like *exec.ExitError) if cmd.Start or cmd.Wait() fail. Also at most one error is returned, though multiple may be possible at the same time. (e.g. IO errors on multiple pipes simultaneously)
func NewIOError ¶
Click to show internal directories.
Click to hide internal directories.